@@ -1,8 +1,8 @@
-from ..provider import AsyncBlobStorageProvider
+from ..provider import BlobStorageProvider
 from csengine.extentions.redis.clients.aioredis import AioRedisClient
 
 
-class AioRedisBlobStorageProvider(AsyncBlobStorageProvider):
+class AioRedisBlobStorageProvider(BlobStorageProvider):
     client_class = AioRedisClient
 
     def __init__(self, url, ttl=None):
