@@ -12,11 +12,11 @@ class CloudBlobStorageProvider(BlobStorageProvider):
         self._read_timeout = read_timeout
         self._client = self.client_class()
 
-    def _upload(self, name, data, chunk_size=None):
+    async def _upload(self, name, data, chunk_size=None):
         return self._client.upload(self._bucket, name, data, chunk_size=chunk_size)
 
-    def download(self, name: str, dest: str, chunk_size: int = None):
+    async def download(self, name: str, dest: str, chunk_size: int = None):
         return self._client.download(self._bucket, name, dest, chunk_size)
 
-    def delete(self, name: str):
-        return self._client.delete(name)
\ No newline at end of file
+    async def delete(self, name: str):
+        return self._client.delete(self._bucket, name)
