@@ -1,8 +1,8 @@
-from ..provider import AsyncBlobStorageProvider
+from ..provider import BlobStorageProvider
 from csengine.extentions.gcloud.clients.aio_storage import AioGCloudStorageClient
 
 
-class AioCloudBlobStorageProvider(AsyncBlobStorageProvider):
+class AioCloudBlobStorageProvider(BlobStorageProvider):
     client_class = AioGCloudStorageClient
 
     def __init__(self, bucket, conn_timeout=None, read_timeout=None):
