@@ -12,7 +12,7 @@ class LocalFSBlobProvider(BlobStorageProvider):
         # shutil.rmtree(self._root_dir, ignore_errors=True)
         os.makedirs(self._root_dir, exist_ok=True)
 
-    def upload(self, data: Any, name=None, chunk_size: int = None):
+    async def upload(self, data: Any, name=None, chunk_size: int = None):
         file_name = os.path.join(self._root_dir, name)
         os.makedirs(os.path.dirname(file_name), exist_ok=True)
         if isinstance(data, bytes):
@@ -22,12 +22,12 @@ class LocalFSBlobProvider(BlobStorageProvider):
                 for chunk in iter(lambda: data.read(chunk_size), b''):
                     f.write(chunk)
 
-    def download(self, name, dest, chunk_size=65536):
+    async def download(self, name, dest, chunk_size=65536):
         file_name = os.path.join(self._root_dir, name)
         shutil.copy2(file_name, dest)
         return file_name
 
-    def delete(self, name: str):
+    async def delete(self, name: str):
         file_name = os.path.join(self._root_dir, name)
         if os.path.exists(file_name):
             os.remove(file_name)
