@@ -10,14 +10,14 @@ class RedisBlobStorageProvider(BlobStorageProvider):
         self._ttl = ttl
         self._client = self.client_class(url)
 
-    def _upload(self, name, data, chunk_size=None):
+    async def _upload(self, name, data, chunk_size=None):
         if not any(isinstance(data, _type) for _type in [bytearray, bytes, float, int, str]):
             data = data.read()
         return self._client.set(name, data)
 
-    def _download(self, name, chunk_size=None):
+    async def _download(self, name, chunk_size=None):
         return self._client.get(name)
 
-    def delete(self, name: str):
+    async def delete(self, name: str):
         return self._client.delete(name)
 
