@@ -13,30 +13,17 @@ class ModelManager:
     def set_provider(self, provider):
         self._provider = provider
 
-    def create(self, **values):
+    async def create(self, **values):
         raise NotImplementedError()
 
-    def get(self, pk):
-        return self._provider.get(self._model, pk)
-
-    def select(self, filt):
-        raise NotImplementedError()
-
-    def select_object(self, **filt):
-        objects = self.select(filt)
-        return objects[0] if objects else None
-
-    async def async_create(self, **values):
-        raise NotImplementedError()
-
-    async def async_get(self, pk):
+    async def get(self, pk):
         return await self._provider.get(self._model, pk)
 
-    async def async_select(self, filt):
+    async def select(self, filt):
         raise NotImplementedError()
 
-    async def async_select_object(self, **filt):
-        objects = await self.async_select(filt)
+    async def select_object(self, **filt):
+        objects = await self.select(filt)
         return objects[0] if objects else None
 
     def wrap(self, values):
@@ -48,14 +35,8 @@ class ModelManager:
 
 class KVModelManager(ModelManager):
 
-    async def async_create(self, **values):
+    async def create(self, **values):
         pk = values.get(self._model.Meta.pk_field) or self.generate_key(**values)
         values = dict(values, **{self._model.Meta.pk_field: pk})
         await self._provider.create(self._model, pk, values)
         return self.wrap(values)
-
-    def create(self, **values):
-        pk = values.get(self._model.Meta.pk_field) or self.generate_key(**values)
-        values = dict(values, **{self._model.Meta.pk_field: pk})
-        self._provider.create(self._model, pk, values)
-        return self.wrap(values)
