@@ -1,15 +1,17 @@
 import importlib
 import pkgutil
+from types import ModuleType
+from typing import Any, Union, Dict
 
 
-def import_path(name):
+def import_path(name: str) -> Any:
     """Return an attribute from a dotted path name (e.g. "path.to.func")."""
     module_name, attribute = name.rsplit('.', 1)
     module = importlib.import_module(module_name)
     return getattr(module, attribute)
 
 
-def import_submodules(package, recursive=True):
+def import_submodules(package: Union[str, ModuleType], recursive: bool = True) -> Dict[str, ModuleType]:
     if isinstance(package, str):
         package = importlib.import_module(package)
     results = {}
