@@ -1,4 +1,5 @@
 from logging import config
+from typing import Any, Dict
 
 DEFAULT_CONFIG = {
     'version': 1,
@@ -22,5 +23,5 @@ DEFAULT_CONFIG = {
 }
 
 
-def setup_logging(configuration=None):
+def setup_logging(configuration: Dict[str, Any] = None):
     config.dictConfig(configuration or DEFAULT_CONFIG)
